===================
hiperwalk.Hypercube
===================

.. currentmodule:: hiperwalk

.. autofunction:: Hypercube

Methods
-------

Besides all methods inherited from
:class:`hiperwalk.Graph`,
:class:`hiperwalk.Multigraph`,
or :class:`hiperwalk.WeightedGraph`,
a hypercube instance also has the following method.

.. currentmodule:: hiperwalk.graph.hypercube

.. autosummary::
   :toctree: generated

   dimension
